pub fn unity_re<P, E, V>(a: V, b: V, q: V, plan: &PolylogPlan<E>) -> VExpand description
The real part of the unity series at mu = a + ib, including the fused or plain lead
term. q = |mu|^2. See the module docs for the identities.
pub fn unity_re<P, E, V>(a: V, b: V, q: V, plan: &PolylogPlan<E>) -> VThe real part of the unity series at mu = a + ib, including the fused or plain lead
term. q = |mu|^2. See the module docs for the identities.